@@ -1,4 +1,4 @@
-from typing import Any, List, Optional, cast, Union, overload, Sequence
+from typing import Any, List, Optional, cast, Union, overload, Sequence, Iterable
 
 from .functions import RemoteFunction
 from .hints import SkillCode, Symbol, Var
@@ -39,15 +39,28 @@ class RemoteObject:
 
     @property
     def skill_id(self) -> int:
-        return int(self._variable[5:].rsplit('_', maxsplit=1)[1], 0)
+        addr = self._variable[5:].rsplit('_', maxsplit=1)[1]
+        try:
+            return int(addr, 0)
+        except ValueError:
+            return int(addr, 16)
 
     @property
     def skill_parent_type(self) -> str:
         return self._variable[5:].rsplit('_', maxsplit=1)[0]
 
+    def _is_open_file(self) -> bool:
+        return self._variable.startswith('__py_openfile_')
+
     @property
     def skill_type(self) -> Optional[str]:
-        typ = self.obj_type
+        if self._is_open_file():
+            return 'open_file'
+
+        try:
+            typ = self.obj_type
+        except RuntimeError:
+            return None
         if typ is None:
             return None
         if isinstance(typ, Symbol):
@@ -62,11 +75,18 @@ class RemoteObject:
 
     def __str__(self) -> str:
         typ = self.skill_type or self.skill_parent_type
+        if typ == 'open_file':
+            result = self._send(self._translate.encode_call('sprintf', None, '%s', self))
+            name = self._translate.decode(result)[6:-1]  # type: ignore
+            return f"<remote open_file {name!r}>"
         return f"<remote {typ}@{hex(self.skill_id)}>"
 
     __repr__ = __str__
 
-    def __dir__(self) -> List[str]:
+    def __dir__(self) -> Iterable[str]:
+        if self._is_open_file():
+            return super().__dir__()
+
         response = self._send(self._translate.encode_dir(self._variable))
         attributes = self._translate.decode_dir(response)
         return attributes
@@ -98,6 +118,11 @@ class RemoteObject:
             return self._variable != other._variable
         return NotImplemented
 
+    def __call__(self, *args: Any, **kwargs: Any) -> Any:
+        command = self._translate.encode_call('funcall', self, *args, **kwargs)
+        result = self._channel.send(command)
+        return self._translate.decode(result)
+
     @property
     def lazy(self) -> 'LazyList':
         return LazyList(self._channel, self._variable, self._translate)
