@@ -41,9 +41,9 @@ def snake_to_camel(snake: str) -> str:
 def camel_to_snake(camel: str) -> str:
     if camel[0].isupper():
         return camel
-    parts = findall("[a-z]+|[A-Z][a-z]+|[A-Z]+(?=[A-Z_][a-z]|$)", camel)
+    parts = findall("[a-z0-9]+|[A-Z][a-z0-9]+|[A-Z]+(?=[A-Z_][a-z]|$)", camel)
     return '_'.join(
-        part.lower() if part[-1].islower() or len(part) == 1 else part for part in parts
+        part.lower() if not part[-1].isupper() or len(part) == 1 else part for part in parts
     )
 
 
@@ -118,7 +118,14 @@ class Translator:
 
     @staticmethod
     def encode_dir(obj: SkillCode) -> SkillCode:
-        parts = ' '.join((f'{obj}->?', f'{obj}->systemHandleNames', f'{obj}->userHandleNames'))
+
+        parts = ' '.join(
+            (
+                f'{obj}->?',
+                f"if( type({obj}) == 'rodObj then {obj}->systemHandleNames)",
+                f'if( type({obj}) == \'rodObj then {obj}->userHandleNames)',
+            )
+        )
         code = f'mapcar(lambda((attr) sprintf(nil "%s" attr)) nconc({parts}))'
         return SkillCode(code)
 
