@@ -324,3 +324,36 @@ def test_warning_is_printed(server, ws):
     assert "This is a warning" in str(w[0].message)
 
     assert result == 1234
+
+
+def test_funcall_shortcut(server, ws):
+    server.answer_object('testfun', 123)
+    fun = ws.ge.get_edit_cell_view()
+
+    server.answer_success('42')
+    assert fun() == 42
+    assert server.last_question == 'funcall(__py_testfun_123 )'
+
+    server.answer_success('41')
+    assert fun(1, 2, 3) == 41
+    assert server.last_question == 'funcall(__py_testfun_123 1 2 3 )'
+
+    server.answer_success('40')
+    assert fun(a=1, b=2, c=3) == 40
+    assert server.last_question == 'funcall(__py_testfun_123 ?a 1 ?b 2 ?c 3)'
+
+    server.answer_success('39')
+    assert fun(10, 20, 30, a=1, b=2, c=3) == 39
+    assert server.last_question == 'funcall(__py_testfun_123 10 20 30 ?a 1 ?b 2 ?c 3)'
+
+
+def test_open_file(server, ws):
+    server.answer_object('openfile', 22)
+    f = ws.ge.get_edit_cell_view()
+
+    assert f.skill_type == 'open_file'
+    server.answer_success("'port:\"test.txt\"'")
+    assert str(f) == "<remote open_file 'test.txt'>"
+    assert server.last_question == 'sprintf(nil "%s" __py_openfile_22 )'
+
+    assert dir(f)
